==> enterprisemodules-ora_install-3.0.12.tar.gz: enterprisemodules-ora_install-3.0.12/README.md <==
[![Enterprise Modules](https://raw.githubusercontent.com/enterprisemodules/public_images/master/banner1.jpg)](https://www.enterprisemodules.com)

#### Table of Contents

1. [Overview](#overview)
2. [License](#license)
3. [Description - What the module does and why it is useful](#description)
4. [Setup](#setup)
  * [Requirements](#requirements)
  * [Installing the ora_install module](#installing-the-ora_install-module)
5. [Usage - Configuration options and additional functionality](#usage)
6. [Reference - An under-the-hood peek at what the module is doing and how](#reference)
7. [Limitations - OS compatibility, etc.](#limitations)

## Overview

This module allows you to install multiple Oracle database related products. It is part of our family of Puppet modules to install, manage and secure Oracle databases with Puppet. Besides the [`ora_install`](https://www.enterprisemodules.com/shop/products/puppet-ora_install-module?taxon_id=14) module, this family also contains:

- [ora_config](https://www.enterprisemodules.com/shop/products/puppet-ora_config-module?taxon_id=14) For configuring every aspect of your Oracle database
- [ora_cis](https://www.enterprisemodules.com/shop/products/puppet-oracle-security-module?taxon_id=14) To secure your databases according to the CIS benchmarks.
- [ora_rac]() To use Puppet to create and manage Oracle RAC installations.

## License

This is a commercially licensed module. But you can use the module on VirtualBox based development systems for **FREE**. When used on **real** systems a license is required.

You can license our modules in multiple ways. Our basic licensing model requires a subscription per node. But [contact](https://www.enterprisemodules.com/company/contact/) us for details.

Check the [License](https://forge.puppet.com/enterprisemodules/ora_install/license) for details.

## Description

The ora_install module contains all Puppet classes, defined types and custom types needed to install Oracle RDBMS and Oracle ASM on a system. Instead of writing complex Bash scripts, using this module, you can now define your Oracle software installation in an easy declarative way. 

All knowledge required to install and manage your Oracle installation is coded into the puppet modules. This means they can focus on the “what” and leave the implementation details to our modules.

Our modules support a broad range of Oracle versions. We are committed to making our modules work on future releases. This allows our customers an easy upgrade path from older to newer versions.

The module has support for:

- [installasm](https://www.enterprisemodules.com/docs/ora_install/installasm.html) Install the ASM Grid software
- [installdb](https://www.enterprisemodules.com/docs/ora_install/installdb.html) Instal the Oracle Database software
- [installem](https://www.enterprisemodules.com/docs/ora_install/installem.html) Install Enterprise Manager software
- [installem_agent](https://www.enterprisemodules.com/docs/ora_install/installem_agent.html) Instal the Enterprise Manager Agent software
- [goldengate](https://www.enterprisemodules.com/docs/ora_install/goldengate.html) Install the goldengate software
- [client](https://www.enterprisemodules.com/docs/ora_install/client.html) Install the Oracle client software
- [database](https://www.enterprisemodules.com/docs/ora_install/database.html) Create a simple databases
- [db_listener](https://www.enterprisemodules.com/docs/ora_install/db_listener.html) Start the listener
- [net](https://www.enterprisemodules.com/docs/ora_install/net.html) Install and configure SQL*Net
- [opatchupgrade](https://www.enterprisemodules.com/docs/ora_install/opatchupgrade.html) Ensure the correct Opatch version on your system
- [rcu](https://www.enterprisemodules.com/docs/ora_install/rcu.html) Create a Fusion Reporsitory
- [tnsnames]https://www.enterprisemodules.com/docs/ora_install/tnsnames.html) Manage TNS names entries

## Setup

### Requirements

The [`ora_install`](https://www.enterprisemodules.com/shop/products/puppet-ora_install-module?taxon_id=14) module requires:

- Puppet module [`enterprisemodules-easy_type`]((https://forge.puppet.com/enterprisemodules/easy_type) installed.
- Puppet version 4.0 or higher. Can be Puppet Enterprise or Puppet Open Source
- Oracle 11 higher
- A valid Oracle license
- A valid Enterprise Modules license for usage.
- Runs on most Linux systems.
- Runs on Solaris
- Windows systems are **NOT** supported

### Installing the ora_install module

To install these modules, you can use a `Puppetfile`

```
mod 'enterprisemodules/ora_install'               ,'3.0.x'
```

Then use the `librarian-puppet` or `r10K` to install the software.

You can also install the software using the `puppet module`  command:

```
puppet module install enterprisemodules-ora_install
```

## Usage

Building a total Oracle setup requires quite some work. To help you, we have built [some examples](https://github.com/enterprisemodules/simple_db_demo). The repo contains a demonstration of a simple database installation. 


## Reference

Here you can find some more information regarding this puppet module:

- [The `ora_install` documentation](https://www.enterprisemodules.com/docs/ora_install/description.html)

Here are a related blog posts:
- [How to ensure you only use Oracle features you paid for](https://www.enterprisemodules.com/blog/2017/09/how-to-ensure-you-only-use-oracle-features-you-paid-for/)
- [Oracle 12.2 support added to our Oracle modules](https://www.enterprisemodules.com/blog/2017/03/oracle12-2-support/)
- [Secure your Oracle Database](https://www.enterprisemodules.com/blog/2017/02/secure-your-oracle-database/)
- [Manage Oracle containers with Puppet](https://www.enterprisemodules.com/blog/2017/01/manage-oracle-containers-with-puppet/)
- [Manage your oracle users with Puppet](https://www.enterprisemodules.com/blog/2016/10/manage-oracle-users-with-puppet/)
- [Reaching into your Oracle Database with Puppet](https://www.enterprisemodules.com/blog/2015/12/reaching-into-your-oracle-database-with-puppet/)
- [Manage your Oracle database schemas with Puppet](https://www.enterprisemodules.com/blog/2015/12/manage-your-oracle-database-schemas-with-puppet/)
- [Managing your Oracle database size with Puppet](https://www.enterprisemodules.com/blog/2015/11/managing-your-oracle-database-size-with-puppet/)
- [Using Puppet to manage Oracle](https://www.enterprisemodules.com/blog/2014/02/using-puppet-to-manage-oracle/)


## Limitations

This module runs on Solaris and most Linux versions. It requires a puppet version higher than 4. The module does **NOT** run on windows systems.

==> enterprisemodules-ora_install-4.3.2.tar.gz: enterprisemodules-ora_install-4.3.2/README.md <==
[![Enterprise Modules](https://raw.githubusercontent.com/enterprisemodules/public_images/master/banner1.jpg)](https://www.enterprisemodules.com)

#### Table of Contents

1. [Overview](#overview)
2. [License](#license)
3. [Description - What the module does and why it is useful](#description)
4. [Setup](#setup)
  * [Requirements](#requirements)
  * [Installing the ora_install module](#installing-the-ora_install-module)
5. [Usage - Configuration options and additional functionality](#usage)
6. [Reference - An under-the-hood peek at what the module is doing and how](#reference)
7. [Limitations - OS compatibility, etc.](#limitations)

## Overview

This module allows you to install multiple Oracle database related products. It is part of our family of Puppet modules to install, manage and secure Oracle databases with Puppet. Besides the [`ora_install`](https://www.enterprisemodules.com/shop/products/puppet-ora_install-module?taxon_id=14) module, this family also contains:

- [`ora_config`](https://www.enterprisemodules.com/shop/products/puppet-ora_config-module?taxon_id=14) For configuring every aspect of your Oracle database
- [`ora_cis`](https://www.enterprisemodules.com/shop/products/puppet-oracle-security-module?taxon_id=14) To secure your databases according to the CIS benchmarks.
- [`ora_profile`](https://forge.puppet.com/enterprisemodules/ora_profile) The ora_profile module allows an easy path from first simple installation to a fully customized Enterprise setup. 

All of these modules support Oracle versions 11, 12 and 18.

## License

This is a commercially licensed module. But you can use the module on VirtualBox based development systems for **FREE**. When used on **real** systems a license is required.

You can license our modules in multiple ways. Our basic licensing model requires a subscription per node. But [contact](https://www.enterprisemodules.com/company/contact/) us for details.

Check the [License](https://forge.puppet.com/enterprisemodules/ora_install/license) for details.

## Description

The `ora_install` module contains all Puppet classes, defined types and custom types needed to install Oracle RDBMS and Oracle ASM on a system. Instead of writing complex Bash scripts, using this module, you can now define your Oracle software installation in an easy, declarative way. 

All knowledge required to install and manage your Oracle installation is coded into the Puppet modules. This means you can focus on the "what" and leave the implementation details to our modules.

Our modules support a broad range of Oracle versions. We are committed to making our modules work on future releases. This allows our customers an easy upgrade path from older to newer versions.

The module has support for:

- [installasm](https://www.enterprisemodules.com/docs/ora_install/installasm.html) Install the ASM Grid software
- [installdb](https://www.enterprisemodules.com/docs/ora_install/installdb.html) Install the Oracle Database software
- [installem](https://www.enterprisemodules.com/docs/ora_install/installem.html) Install Enterprise Manager software
- [installem_agent](https://www.enterprisemodules.com/docs/ora_install/installem_agent.html) Install the Enterprise Manager Agent software
- [goldengate](https://www.enterprisemodules.com/docs/ora_install/goldengate.html) Install the goldengate software
- [client](https://www.enterprisemodules.com/docs/ora_install/client.html) Install the Oracle client software
- [database](https://www.enterprisemodules.com/docs/ora_install/database.html) Create a simple databases
- [db_listener](https://www.enterprisemodules.com/docs/ora_install/db_listener.html) Start the listener
- [net](https://www.enterprisemodules.com/docs/ora_install/net.html) Install and configure SQL*Net
- [opatchupgrade](https://www.enterprisemodules.com/docs/ora_install/opatchupgrade.html) Ensure the correct Opatch version on your system
- [rcu](https://www.enterprisemodules.com/docs/ora_install/rcu.html) Create a Fusion Repository
- [tnsnames](https://www.enterprisemodules.com/docs/ora_install/tnsnames.html) Manage TNS names entries

## Setup

### Requirements

The [`ora_install`](https://www.enterprisemodules.com/shop/products/puppet-ora_install-module?taxon_id=14) module requires:

- Puppet module [`enterprisemodules-easy_type`]((https://forge.puppet.com/enterprisemodules/easy_type) installed.
- Puppet version 4.0 or higher. Can be Puppet Enterprise or Puppet Open Source
- Oracle 11 or higher, including support for Oracle 18
- A valid Oracle license
- A valid Enterprise Modules license for usage
- Runs on most Linux systems
- Runs on Solaris
- Windows systems are **NOT** supported

### Installing the ora_install module

To install these modules, you can use a `Puppetfile`

```
mod 'enterprisemodules/ora_install', '3.0.x'
```

Then use the `librarian-puppet` or `r10K` to install the software.

You can also install the software using the `puppet module` command:

```
puppet module install enterprisemodules-ora_install
```

## Usage

Building a total Oracle setup requires quite some work. To help you, we have built [some examples](https://github.com/enterprisemodules/simple_db_demo). This repo contains a demonstration of a simple database installation. 

## Reference

You can find some more information here regarding this Puppet module:

- [The `ora_install` documentation](https://www.enterprisemodules.com/docs/ora_install/description.html)

And here are some related blog posts:
- [How to ensure you only use Oracle features you paid for](https://www.enterprisemodules.com/blog/2017/09/how-to-ensure-you-only-use-oracle-features-you-paid-for/)
- [Oracle 12.2 support added to our Oracle modules](https://www.enterprisemodules.com/blog/2017/03/oracle12-2-support/)
- [Secure your Oracle database](https://www.enterprisemodules.com/blog/2017/02/secure-your-oracle-database/)
- [Manage Oracle containers with Puppet](https://www.enterprisemodules.com/blog/2017/01/manage-oracle-containers-with-puppet/)
- [Manage your Oracle users with Puppet](https://www.enterprisemodules.com/blog/2016/10/manage-oracle-users-with-puppet/)
- [Reaching into your Oracle database with Puppet](https://www.enterprisemodules.com/blog/2015/12/reaching-into-your-oracle-database-with-puppet/)
- [Manage your Oracle database schemas with Puppet](https://www.enterprisemodules.com/blog/2015/12/manage-your-oracle-database-schemas-with-puppet/)
- [Managing your Oracle database size with Puppet](https://www.enterprisemodules.com/blog/2015/11/managing-your-oracle-database-size-with-puppet/)
- [Using Puppet to manage Oracle](https://www.enterprisemodules.com/blog/2014/02/using-puppet-to-manage-oracle/)


## Limitations

This module runs on Solaris and most Linux versions. It requires a puppet version higher than 4. The module does **NOT** run on Windows systems.
